import java.util.LinkedList;

/**
 * A node that is used in our implementation of BinomialHeaps.
 */
public class BinHeapNode {
	/**
	 * The parent of the node.
	 */
	private BinHeapNode parent;
	/**
	 * The current value of the node.
	 */
	private int data;
	/**
	 * A {@link LinkedList} of all children of this node. Note that the list is sorted by non-decreasing index of the root-nodes.
	 */
	private LinkedList<BinHeapNode> childrenSorted;
	/**
	 * The subtree of the node corresponds to a binomial tree with the specified index.
	 */
	private int index;
	
	/**
	 * Creates a new {@link BinHeapNode} with stores the specified data. 
	 * @param data The value of the node.
	 */
	public BinHeapNode(int data) {
		this.childrenSorted = new LinkedList<BinHeapNode> ();
		this.data = data;
		this.index = 0;
	}
	/**
	 * @return the parent node
	 */
	public BinHeapNode getParent() {
		return parent;
	}
	/**
	 * @param parent the parent to set
	 */
	public void setParent(BinHeapNode parent) {
		this.parent = parent;
	}
	/**
	 * @return the data in the node
	 */
	public int getData() {
		return data;
	}
	/**
	 * @param data the data to set
	 */
	public void setData(int data) {
		this.data = data;
	}
	/**
	 * @return the list of children
	 */
	public LinkedList<BinHeapNode> getChildrenSorted() {
		return childrenSorted;
	}
	/**
	 * @param child the child to add to the sorted list of children
	 */
	public void addChild(BinHeapNode child) {
		// TODO: Add your code here! 
	}
	
	/**
	 * @return the index
	 */
	public int getIndex() {
		return index;
	}
	/**
	 * @param index the index to set
	 */
	public void setIndex(int index) {
		this.index = index;
	}
			
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder("[(" + data + ")");
		if (!(childrenSorted==null) && !childrenSorted.isEmpty()) {
			for(BinHeapNode node : this.childrenSorted) {
				sb.append(node.toString());
			}
		}
		sb.append("]");
		return sb.toString();
	}
}
